# DiscordFilter
Use This To Find Filtered Discord Words Like Nitro Scams

[![Downloads](https://pepy.tech/badge/DiscordFilter)](https://pepy.tech/project/DiscordFilter)
[![Downloads](https://pepy.tech/badge/DiscordFilter/week)](https://pepy.tech/project/DiscordFilter)
[![Downloads](https://pepy.tech/badge/DiscordFilter/month)](https://pepy.tech/project/DiscordFilter)
[![Requires: Python 3.x](https://img.shields.io/pypi/pyversions/DiscordFilter.svg)](https://pypi.org/project/DiscordFilter/)
[![Version: 0.0.2](https://img.shields.io/pypi/v/DiscordFilter.svg)](https://pypi.org/project/DiscordFilter/)

### Setup:
``pip3 install DiscordFilter``

[Github](https://github.com/DiscordFilter "github.com/PirxcyFinal/DiscordFilter")

